@@ -1,5 +1,8 @@
 import pytest
 
+from sscutils.artifact_context import ArtifactContext
+from sscutils.exceptions import NotAnArtifactException
+from sscutils.utils import cd_into
 from sscutils.validation_functions import (
     validate_repo_name,
     validate_step_name,
@@ -42,3 +45,9 @@ def test_step_name_valid(step_name, is_valid):
     else:
         with pytest.raises(NameError):
             validate_step_name(step_name)
+
+
+def test_failing_config(tmp_path):
+    with cd_into(tmp_path):
+        with pytest.raises(NotAnArtifactException):
+            ArtifactContext()
